summaryrefslogtreecommitdiffstats
path: root/sysdep/linux
diff options
context:
space:
mode:
authorOndrej Zajicek <santiago@crfreenet.org>2011-03-28 22:46:18 +0200
committerOndrej Zajicek <santiago@crfreenet.org>2011-03-28 22:46:18 +0200
commit52a43ae3b76f86b697537bc3ad8afdb3b421cf2c (patch)
tree15a006b41f3e166c75f46f1ea45cc4fcb1502f5d /sysdep/linux
parentc454872f4e81e69a8e9950289ab810fcac3fc922 (diff)
downloadbird-52a43ae3b76f86b697537bc3ad8afdb3b421cf2c.tar
bird-52a43ae3b76f86b697537bc3ad8afdb3b421cf2c.zip
Minor changes in addresses.
Mainly changes IA_UNNUMBERED to IA_PEER and adds IA_HOST. Also do not show broadcast addr in show interfaces. Nobody cares for that.
Diffstat (limited to 'sysdep/linux')
-rw-r--r--sysdep/linux/netlink/netlink.c8
1 files changed, 5 insertions, 3 deletions
diff --git a/sysdep/linux/netlink/netlink.c b/sysdep/linux/netlink/netlink.c
index 3eaa53a..afca626 100644
--- a/sysdep/linux/netlink/netlink.c
+++ b/sysdep/linux/netlink/netlink.c
@@ -499,10 +499,12 @@ nl_parse_addr(struct nlmsghdr *h)
ipa_ntoh(addr);
ifa.prefix = ifa.brd = addr;
- /* It is either a peer address, or loopback/dummy address */
- if (!ipa_equal(ifa.ip, addr))
+ /* It is either a host address or a peer address */
+ if (ipa_equal(ifa.ip, addr))
+ ifa.flags |= IA_HOST;
+ else
{
- ifa.flags |= IA_UNNUMBERED;
+ ifa.flags |= IA_PEER;
ifa.opposite = addr;
}
}